@@ -3,7 +3,7 @@ from __future__ import print_function
 import sys, time, json
 import socket
 
-__version__ = '2.3.2'
+__version__ = '2.3.3'
 
 READ_BUF_LEN = 1300
 TIME_WAIT_SEND_S = 3
@@ -293,11 +293,10 @@ class Runable(Base):
         while self._dog_runing:
             now = int_time()
             if (now - self._dog_last) > TIME_FOR_DOG_TIMEOUT:
-                print(self, 'dog time out', now, self._dog_last)
+                self._log('dog time out', now, self._dog_last)
                 if not self._on_dog_timeout():
                     exit_system(-1)
             time.sleep(1)
-            print('ck', self._dog_last)
 
     def stop_dog(self):
         self._dog_runing = False
